# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/communicationpatterns/TaskState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/communicationpatterns/TaskState.proto',
  package='rst.communicationpatterns',
  syntax='proto2',
  serialized_pb=_b('\n)rst/communicationpatterns/TaskState.proto\x12\x19rst.communicationpatterns\"\x90\x03\n\tTaskState\x12;\n\x06origin\x18\x01 \x02(\x0e\x32+.rst.communicationpatterns.TaskState.Origin\x12\x39\n\x05state\x18\x02 \x02(\x0e\x32*.rst.communicationpatterns.TaskState.State\x12\x0e\n\x06serial\x18\x03 \x02(\r\x12\x13\n\x0bwire_schema\x18\x04 \x02(\x0c\x12\x0f\n\x07payload\x18\x05 \x02(\x0c\"\xae\x01\n\x05State\x12\r\n\tINITIATED\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\x13\n\x0fUPDATE_REJECTED\x10\x04\x12\t\n\x05\x41\x42ORT\x10\x05\x12\x0b\n\x07\x41\x42ORTED\x10\x06\x12\x10\n\x0c\x41\x42ORT_FAILED\x10\x07\x12\x14\n\x10RESULT_AVAILABLE\x10\x08\x12\r\n\tCOMPLETED\x10\t\x12\n\n\x06\x46\x41ILED\x10\n\"$\n\x06Origin\x12\r\n\tSUBMITTER\x10\x00\x12\x0b\n\x07HANDLER\x10\x01\x42\x0f\x42\rTaskStateType')
)



_TASKSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='rst.communicationpatterns.TaskState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INITIATED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_REJECTED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORT_FAILED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_AVAILABLE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=261,
  serialized_end=435,
)
_sym_db.RegisterEnumDescriptor(_TASKSTATE_STATE)

_TASKSTATE_ORIGIN = _descriptor.EnumDescriptor(
  name='Origin',
  full_name='rst.communicationpatterns.TaskState.Origin',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUBMITTER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HANDLER', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=437,
  serialized_end=473,
)
_sym_db.RegisterEnumDescriptor(_TASKSTATE_ORIGIN)


_TASKSTATE = _descriptor.Descriptor(
  name='TaskState',
  full_name='rst.communicationpatterns.TaskState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='rst.communicationpatterns.TaskState.origin', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.communicationpatterns.TaskState.state', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serial', full_name='rst.communicationpatterns.TaskState.serial', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wire_schema', full_name='rst.communicationpatterns.TaskState.wire_schema', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='rst.communicationpatterns.TaskState.payload', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TASKSTATE_STATE,
    _TASKSTATE_ORIGIN,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=473,
)

_TASKSTATE.fields_by_name['origin'].enum_type = _TASKSTATE_ORIGIN
_TASKSTATE.fields_by_name['state'].enum_type = _TASKSTATE_STATE
_TASKSTATE_STATE.containing_type = _TASKSTATE
_TASKSTATE_ORIGIN.containing_type = _TASKSTATE
DESCRIPTOR.message_types_by_name['TaskState'] = _TASKSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TaskState = _reflection.GeneratedProtocolMessageType('TaskState', (_message.Message,), dict(
  DESCRIPTOR = _TASKSTATE,
  __module__ = 'rst.communicationpatterns.TaskState_pb2'
  # @@protoc_insertion_point(class_scope:rst.communicationpatterns.TaskState)
  ))
_sym_db.RegisterMessage(TaskState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rTaskStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/SoundChunk.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/SoundChunk.proto',
  package='rst.audition',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/audition/SoundChunk.proto\x12\x0crst.audition\"\x85\x03\n\nSoundChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\x14\n\x0csample_count\x18\x02 \x02(\r\x12\x13\n\x08\x63hannels\x18\x03 \x01(\r:\x01\x31\x12\x13\n\x04rate\x18\x04 \x01(\r:\x05\x34\x34\x31\x30\x30\x12\x44\n\x0bsample_type\x18\x05 \x01(\x0e\x32#.rst.audition.SoundChunk.SampleType:\nSAMPLE_S16\x12\x46\n\nendianness\x18\x06 \x01(\x0e\x32#.rst.audition.SoundChunk.EndianNess:\rENDIAN_LITTLE\"j\n\nSampleType\x12\r\n\tSAMPLE_S8\x10\x00\x12\r\n\tSAMPLE_U8\x10\x01\x12\x0e\n\nSAMPLE_S16\x10\x02\x12\x0e\n\nSAMPLE_U16\x10\x04\x12\x0e\n\nSAMPLE_S24\x10\x08\x12\x0e\n\nSAMPLE_U24\x10\x10\"/\n\nEndianNess\x12\x11\n\rENDIAN_LITTLE\x10\x00\x12\x0e\n\nENDIAN_BIG\x10\x01\x42\x10\x42\x0eSoundChunkType')
)



_SOUNDCHUNK_SAMPLETYPE = _descriptor.EnumDescriptor(
  name='SampleType',
  full_name='rst.audition.SoundChunk.SampleType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_S8', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_U8', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_S16', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_U16', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_S24', index=4, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_U24', index=5, number=16,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=282,
  serialized_end=388,
)
_sym_db.RegisterEnumDescriptor(_SOUNDCHUNK_SAMPLETYPE)

_SOUNDCHUNK_ENDIANNESS = _descriptor.EnumDescriptor(
  name='EndianNess',
  full_name='rst.audition.SoundChunk.EndianNess',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENDIAN_LITTLE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENDIAN_BIG', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=390,
  serialized_end=437,
)
_sym_db.RegisterEnumDescriptor(_SOUNDCHUNK_ENDIANNESS)


_SOUNDCHUNK = _descriptor.Descriptor(
  name='SoundChunk',
  full_name='rst.audition.SoundChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.audition.SoundChunk.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sample_count', full_name='rst.audition.SoundChunk.sample_count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='rst.audition.SoundChunk.channels', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='rst.audition.SoundChunk.rate', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=44100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sample_type', full_name='rst.audition.SoundChunk.sample_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endianness', full_name='rst.audition.SoundChunk.endianness', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SOUNDCHUNK_SAMPLETYPE,
    _SOUNDCHUNK_ENDIANNESS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=437,
)

_SOUNDCHUNK.fields_by_name['sample_type'].enum_type = _SOUNDCHUNK_SAMPLETYPE
_SOUNDCHUNK.fields_by_name['endianness'].enum_type = _SOUNDCHUNK_ENDIANNESS
_SOUNDCHUNK_SAMPLETYPE.containing_type = _SOUNDCHUNK
_SOUNDCHUNK_ENDIANNESS.containing_type = _SOUNDCHUNK
DESCRIPTOR.message_types_by_name['SoundChunk'] = _SOUNDCHUNK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SoundChunk = _reflection.GeneratedProtocolMessageType('SoundChunk', (_message.Message,), dict(
  DESCRIPTOR = _SOUNDCHUNK,
  __module__ = 'rst.audition.SoundChunk_pb2'
  # @@protoc_insertion_point(class_scope:rst.audition.SoundChunk)
  ))
_sym_db.RegisterMessage(SoundChunk)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016SoundChunkType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Recurrence.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import RecurrenceRule_pb2 as rst_dot_calendar_dot_RecurrenceRule__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Recurrence.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/calendar/Recurrence.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a!rst/calendar/RecurrenceRule.proto\"\xda\x01\n\nRecurrence\x12\x30\n\x10recurrence_dates\x18\x01 \x03(\x0b\x32\x16.rst.calendar.DateTime\x12\x36\n\x10recurrence_rules\x18\x02 \x03(\x0b\x32\x1c.rst.calendar.RecurrenceRule\x12-\n\rexclude_dates\x18\x03 \x03(\x0b\x32\x16.rst.calendar.DateTime\x12\x33\n\rexclude_rules\x18\x04 \x03(\x0b\x32\x1c.rst.calendar.RecurrenceRuleB\x10\x42\x0eRecurrenceType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_RecurrenceRule__pb2.DESCRIPTOR,])




_RECURRENCE = _descriptor.Descriptor(
  name='Recurrence',
  full_name='rst.calendar.Recurrence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recurrence_dates', full_name='rst.calendar.Recurrence.recurrence_dates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence_rules', full_name='rst.calendar.Recurrence.recurrence_rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exclude_dates', full_name='rst.calendar.Recurrence.exclude_dates', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exclude_rules', full_name='rst.calendar.Recurrence.exclude_rules', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=330,
)

_RECURRENCE.fields_by_name['recurrence_dates'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_RECURRENCE.fields_by_name['recurrence_rules'].message_type = rst_dot_calendar_dot_RecurrenceRule__pb2._RECURRENCERULE
_RECURRENCE.fields_by_name['exclude_dates'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_RECURRENCE.fields_by_name['exclude_rules'].message_type = rst_dot_calendar_dot_RecurrenceRule__pb2._RECURRENCERULE
DESCRIPTOR.message_types_by_name['Recurrence'] = _RECURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Recurrence = _reflection.GeneratedProtocolMessageType('Recurrence', (_message.Message,), dict(
  DESCRIPTOR = _RECURRENCE,
  __module__ = 'rst.calendar.Recurrence_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Recurrence)
  ))
_sym_db.RegisterMessage(Recurrence)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016RecurrenceType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/RotationCollection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/RotationCollection.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n%rst/geometry/RotationCollection.proto\x12\x0crst.geometry\x1a\x1brst/geometry/Rotation.proto\"=\n\x12RotationCollection\x12\'\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x16.rst.geometry.RotationB\x18\x42\x16RotationCollectionType')
  ,
  dependencies=[rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,])




_ROTATIONCOLLECTION = _descriptor.Descriptor(
  name='RotationCollection',
  full_name='rst.geometry.RotationCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.RotationCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=145,
)

_ROTATIONCOLLECTION.fields_by_name['element'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
DESCRIPTOR.message_types_by_name['RotationCollection'] = _ROTATIONCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RotationCollection = _reflection.GeneratedProtocolMessageType('RotationCollection', (_message.Message,), dict(
  DESCRIPTOR = _ROTATIONCOLLECTION,
  __module__ = 'rst.geometry.RotationCollection_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.RotationCollection)
  ))
_sym_db.RegisterMessage(RotationCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\026RotationCollectionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/UserState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/UserState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n#rst/devices/generic/UserState.proto\x12\x13rst.devices.generic\"Q\n\tUserState\x12\x17\n\x0flogged_in_users\x18\x01 \x01(\r\x12\x16\n\x0elogin_sessions\x18\x02 \x01(\r\x12\x13\n\x0blogin_hosts\x18\x03 \x01(\rB\x0f\x42\rUserStateType')
)




_USERSTATE = _descriptor.Descriptor(
  name='UserState',
  full_name='rst.devices.generic.UserState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logged_in_users', full_name='rst.devices.generic.UserState.logged_in_users', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='login_sessions', full_name='rst.devices.generic.UserState.login_sessions', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='login_hosts', full_name='rst.devices.generic.UserState.login_hosts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['UserState'] = _USERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserState = _reflection.GeneratedProtocolMessageType('UserState', (_message.Message,), dict(
  DESCRIPTOR = _USERSTATE,
  __module__ = 'rst.devices.generic.UserState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.UserState)
  ))
_sym_db.RegisterMessage(UserState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rUserStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/Dictionary.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.generic import KeyValuePair_pb2 as rst_dot_generic_dot_KeyValuePair__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/Dictionary.proto',
  package='rst.generic',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/generic/Dictionary.proto\x12\x0brst.generic\x1a\x1erst/generic/KeyValuePair.proto\"8\n\nDictionary\x12*\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x19.rst.generic.KeyValuePairB\x10\x42\x0e\x44ictionaryType')
  ,
  dependencies=[rst_dot_generic_dot_KeyValuePair__pb2.DESCRIPTOR,])




_DICTIONARY = _descriptor.Descriptor(
  name='Dictionary',
  full_name='rst.generic.Dictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='rst.generic.Dictionary.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=133,
)

_DICTIONARY.fields_by_name['entries'].message_type = rst_dot_generic_dot_KeyValuePair__pb2._KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['Dictionary'] = _DICTIONARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dictionary = _reflection.GeneratedProtocolMessageType('Dictionary', (_message.Message,), dict(
  DESCRIPTOR = _DICTIONARY,
  __module__ = 'rst.generic.Dictionary_pb2'
  # @@protoc_insertion_point(class_scope:rst.generic.Dictionary)
  ))
_sym_db.RegisterMessage(Dictionary)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016DictionaryType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/BatteryState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/BatteryState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n&rst/devices/generic/BatteryState.proto\x12\x13rst.devices.generic\"R\n\x0c\x42\x61tteryState\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x02\x12\x14\n\x0c\x63harge_level\x18\x02 \x02(\x02\x12\x1b\n\x13\x62\x61ttery_temperature\x18\x03 \x01(\x02\x42\x12\x42\x10\x42\x61tteryStateType')
)




_BATTERYSTATE = _descriptor.Descriptor(
  name='BatteryState',
  full_name='rst.devices.generic.BatteryState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='rst.devices.generic.BatteryState.current', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='charge_level', full_name='rst.devices.generic.BatteryState.charge_level', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='battery_temperature', full_name='rst.devices.generic.BatteryState.battery_temperature', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=145,
)

DESCRIPTOR.message_types_by_name['BatteryState'] = _BATTERYSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BatteryState = _reflection.GeneratedProtocolMessageType('BatteryState', (_message.Message,), dict(
  DESCRIPTOR = _BATTERYSTATE,
  __module__ = 'rst.devices.generic.BatteryState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.BatteryState)
  ))
_sym_db.RegisterMessage(BatteryState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020BatteryStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Image.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Image.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x16rst/vision/Image.proto\x12\nrst.vision\"\xc3\x03\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\r\x12\x13\n\x08\x63hannels\x18\x04 \x01(\r:\x01\x33\x12\x30\n\x05\x64\x65pth\x18\x05 \x01(\x0e\x32\x17.rst.vision.Image.Depth:\x08\x44\x45PTH_8U\x12:\n\ncolor_mode\x18\x06 \x01(\x0e\x32\x1b.rst.vision.Image.ColorMode:\tCOLOR_RGB\x12>\n\ndata_order\x18\x07 \x01(\x0e\x32\x1b.rst.vision.Image.DataOrder:\rDATA_SEPARATE\"3\n\x05\x44\x65pth\x12\x0c\n\x08\x44\x45PTH_8U\x10\x08\x12\r\n\tDEPTH_16U\x10\x10\x12\r\n\tDEPTH_32F\x10 \"_\n\tColorMode\x12\x13\n\x0f\x43OLOR_GRAYSCALE\x10\x00\x12\r\n\tCOLOR_RGB\x10\x01\x12\r\n\tCOLOR_BGR\x10\x02\x12\r\n\tCOLOR_YUV\x10\x04\x12\x10\n\x0c\x43OLOR_YUV422\x10\x08\"4\n\tDataOrder\x12\x11\n\rDATA_SEPARATE\x10\x00\x12\x14\n\x10\x44\x41TA_INTERLEAVED\x10\x01\x42\x0b\x42\tImageType')
)



_IMAGE_DEPTH = _descriptor.EnumDescriptor(
  name='Depth',
  full_name='rst.vision.Image.Depth',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPTH_8U', index=0, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPTH_16U', index=1, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPTH_32F', index=2, number=32,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=288,
  serialized_end=339,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_DEPTH)

_IMAGE_COLORMODE = _descriptor.EnumDescriptor(
  name='ColorMode',
  full_name='rst.vision.Image.ColorMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLOR_GRAYSCALE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_RGB', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_BGR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_YUV', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLOR_YUV422', index=4, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=341,
  serialized_end=436,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_COLORMODE)

_IMAGE_DATAORDER = _descriptor.EnumDescriptor(
  name='DataOrder',
  full_name='rst.vision.Image.DataOrder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_SEPARATE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_INTERLEAVED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=438,
  serialized_end=490,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_DATAORDER)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='rst.vision.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.vision.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.Image.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.Image.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='rst.vision.Image.channels', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth', full_name='rst.vision.Image.depth', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=8,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color_mode', full_name='rst.vision.Image.color_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_order', full_name='rst.vision.Image.data_order', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGE_DEPTH,
    _IMAGE_COLORMODE,
    _IMAGE_DATAORDER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=490,
)

_IMAGE.fields_by_name['depth'].enum_type = _IMAGE_DEPTH
_IMAGE.fields_by_name['color_mode'].enum_type = _IMAGE_COLORMODE
_IMAGE.fields_by_name['data_order'].enum_type = _IMAGE_DATAORDER
_IMAGE_DEPTH.containing_type = _IMAGE
_IMAGE_COLORMODE.containing_type = _IMAGE
_IMAGE_DATAORDER.containing_type = _IMAGE
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'rst.vision.Image_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.Image)
  ))
_sym_db.RegisterMessage(Image)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tImageType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarUpdate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import Event_pb2 as rst_dot_calendar_dot_Event__pb2
from rst.calendar import Todo_pb2 as rst_dot_calendar_dot_Todo__pb2
from rst.calendar import TimeZone_pb2 as rst_dot_calendar_dot_TimeZone__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarUpdate.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n!rst/calendar/CalendarUpdate.proto\x12\x0crst.calendar\x1a\x18rst/calendar/Event.proto\x1a\x17rst/calendar/Todo.proto\x1a\x1brst/calendar/TimeZone.proto\"\xae\x01\n\x0e\x43\x61lendarUpdate\x12)\n\ttimezones\x18\x03 \x03(\x0b\x32\x16.rst.calendar.TimeZone\x12+\n\x0e\x63hanged_events\x18\x04 \x03(\x0b\x32\x13.rst.calendar.Event\x12)\n\rchanged_todos\x18\x05 \x03(\x0b\x32\x12.rst.calendar.Todo\x12\x19\n\x11removed_entry_ids\x18\x06 \x03(\tB\x14\x42\x12\x43\x61lendarUpdateType')
  ,
  dependencies=[rst_dot_calendar_dot_Event__pb2.DESCRIPTOR,rst_dot_calendar_dot_Todo__pb2.DESCRIPTOR,rst_dot_calendar_dot_TimeZone__pb2.DESCRIPTOR,])




_CALENDARUPDATE = _descriptor.Descriptor(
  name='CalendarUpdate',
  full_name='rst.calendar.CalendarUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezones', full_name='rst.calendar.CalendarUpdate.timezones', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_events', full_name='rst.calendar.CalendarUpdate.changed_events', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_todos', full_name='rst.calendar.CalendarUpdate.changed_todos', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='removed_entry_ids', full_name='rst.calendar.CalendarUpdate.removed_entry_ids', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=306,
)

_CALENDARUPDATE.fields_by_name['timezones'].message_type = rst_dot_calendar_dot_TimeZone__pb2._TIMEZONE
_CALENDARUPDATE.fields_by_name['changed_events'].message_type = rst_dot_calendar_dot_Event__pb2._EVENT
_CALENDARUPDATE.fields_by_name['changed_todos'].message_type = rst_dot_calendar_dot_Todo__pb2._TODO
DESCRIPTOR.message_types_by_name['CalendarUpdate'] = _CALENDARUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalendarUpdate = _reflection.GeneratedProtocolMessageType('CalendarUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CALENDARUPDATE,
  __module__ = 'rst.calendar.CalendarUpdate_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarUpdate)
  ))
_sym_db.RegisterMessage(CalendarUpdate)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022CalendarUpdateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/statemachine/StateChange.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/statemachine/StateChange.proto',
  package='rst.statemachine',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/statemachine/StateChange.proto\x12\x10rst.statemachine\"S\n\x0bStateChange\x12\x12\n\nfrom_state\x18\x01 \x02(\t\x12\x10\n\x08to_state\x18\x02 \x02(\t\x12\r\n\x05\x63\x61use\x18\x03 \x01(\t\x12\x0f\n\x07machine\x18\x04 \x01(\tB\x11\x42\x0fStateChangeType')
)




_STATECHANGE = _descriptor.Descriptor(
  name='StateChange',
  full_name='rst.statemachine.StateChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_state', full_name='rst.statemachine.StateChange.from_state', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_state', full_name='rst.statemachine.StateChange.to_state', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cause', full_name='rst.statemachine.StateChange.cause', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='machine', full_name='rst.statemachine.StateChange.machine', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=139,
)

DESCRIPTOR.message_types_by_name['StateChange'] = _STATECHANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StateChange = _reflection.GeneratedProtocolMessageType('StateChange', (_message.Message,), dict(
  DESCRIPTOR = _STATECHANGE,
  __module__ = 'rst.statemachine.StateChange_pb2'
  # @@protoc_insertion_point(class_scope:rst.statemachine.StateChange)
  ))
_sym_db.RegisterMessage(StateChange)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017StateChangeType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/MatrixDouble.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/MatrixDouble.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/math/MatrixDouble.proto\x12\x08rst.math\"\x9d\x01\n\x0cMatrixDouble\x12)\n\x04size\x18\x01 \x02(\x0b\x32\x1b.rst.math.MatrixDouble.Size\x12)\n\x04\x64\x61ta\x18\x02 \x02(\x0b\x32\x1b.rst.math.MatrixDouble.Data\x1a\x1c\n\x04Size\x12\t\n\x01m\x18\x01 \x02(\r\x12\t\n\x01n\x18\x02 \x02(\r\x1a\x19\n\x04\x44\x61ta\x12\x11\n\x05value\x18\x01 \x03(\x01\x42\x02\x10\x01\x42\x12\x42\x10MatrixDoubleType')
)




_MATRIXDOUBLE_SIZE = _descriptor.Descriptor(
  name='Size',
  full_name='rst.math.MatrixDouble.Size',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='m', full_name='rst.math.MatrixDouble.Size.m', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='n', full_name='rst.math.MatrixDouble.Size.n', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=172,
)

_MATRIXDOUBLE_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='rst.math.MatrixDouble.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rst.math.MatrixDouble.Data.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=199,
)

_MATRIXDOUBLE = _descriptor.Descriptor(
  name='MatrixDouble',
  full_name='rst.math.MatrixDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='rst.math.MatrixDouble.size', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.math.MatrixDouble.data', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MATRIXDOUBLE_SIZE, _MATRIXDOUBLE_DATA, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=199,
)

_MATRIXDOUBLE_SIZE.containing_type = _MATRIXDOUBLE
_MATRIXDOUBLE_DATA.containing_type = _MATRIXDOUBLE
_MATRIXDOUBLE.fields_by_name['size'].message_type = _MATRIXDOUBLE_SIZE
_MATRIXDOUBLE.fields_by_name['data'].message_type = _MATRIXDOUBLE_DATA
DESCRIPTOR.message_types_by_name['MatrixDouble'] = _MATRIXDOUBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MatrixDouble = _reflection.GeneratedProtocolMessageType('MatrixDouble', (_message.Message,), dict(

  Size = _reflection.GeneratedProtocolMessageType('Size', (_message.Message,), dict(
    DESCRIPTOR = _MATRIXDOUBLE_SIZE,
    __module__ = 'rst.math.MatrixDouble_pb2'
    # @@protoc_insertion_point(class_scope:rst.math.MatrixDouble.Size)
    ))
  ,

  Data = _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), dict(
    DESCRIPTOR = _MATRIXDOUBLE_DATA,
    __module__ = 'rst.math.MatrixDouble_pb2'
    # @@protoc_insertion_point(class_scope:rst.math.MatrixDouble.Data)
    ))
  ,
  DESCRIPTOR = _MATRIXDOUBLE,
  __module__ = 'rst.math.MatrixDouble_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.MatrixDouble)
  ))
_sym_db.RegisterMessage(MatrixDouble)
_sym_db.RegisterMessage(MatrixDouble.Size)
_sym_db.RegisterMessage(MatrixDouble.Data)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020MatrixDoubleType'))
_MATRIXDOUBLE_DATA.fields_by_name['value'].has_options = True
_MATRIXDOUBLE_DATA.fields_by_name['value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Organizer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Organizer.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/calendar/Organizer.proto\x12\x0crst.calendar\"p\n\tOrganizer\x12\x18\n\x10\x63\x61lendar_address\x18\x01 \x02(\t\x12\x13\n\x0b\x63ommon_name\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\x12\x0f\n\x07sent_by\x18\x04 \x01(\t\x12\x10\n\x08language\x18\x05 \x01(\tB\x0f\x42\rOrganizerType')
)




_ORGANIZER = _descriptor.Descriptor(
  name='Organizer',
  full_name='rst.calendar.Organizer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calendar_address', full_name='rst.calendar.Organizer.calendar_address', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common_name', full_name='rst.calendar.Organizer.common_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directory', full_name='rst.calendar.Organizer.directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_by', full_name='rst.calendar.Organizer.sent_by', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='rst.calendar.Organizer.language', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=158,
)

DESCRIPTOR.message_types_by_name['Organizer'] = _ORGANIZER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Organizer = _reflection.GeneratedProtocolMessageType('Organizer', (_message.Message,), dict(
  DESCRIPTOR = _ORGANIZER,
  __module__ = 'rst.calendar.Organizer_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Organizer)
  ))
_sym_db.RegisterMessage(Organizer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rOrganizerType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/Posture3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2
from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/Posture3DFloat.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n#rst/kinematics/Posture3DFloat.proto\x12\x0erst.kinematics\x1a\x1brst/geometry/Rotation.proto\x1a\x1erst/geometry/Translation.proto\"u\n\x0ePosture3DFloat\x12+\n\x08position\x18\x02 \x03(\x0b\x32\x19.rst.geometry.Translation\x12(\n\x08rotation\x18\x03 \x03(\x0b\x32\x16.rst.geometry.Rotation\x12\x0c\n\x04name\x18\x04 \x03(\x0c\x42\x14\x42\x12Posture3DFloatType')
  ,
  dependencies=[rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,])




_POSTURE3DFLOAT = _descriptor.Descriptor(
  name='Posture3DFloat',
  full_name='rst.kinematics.Posture3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.kinematics.Posture3DFloat.position', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='rst.kinematics.Posture3DFloat.rotation', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.kinematics.Posture3DFloat.name', index=2,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=233,
)

_POSTURE3DFLOAT.fields_by_name['position'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
_POSTURE3DFLOAT.fields_by_name['rotation'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
DESCRIPTOR.message_types_by_name['Posture3DFloat'] = _POSTURE3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Posture3DFloat = _reflection.GeneratedProtocolMessageType('Posture3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _POSTURE3DFLOAT,
  __module__ = 'rst.kinematics.Posture3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.Posture3DFloat)
  ))
_sym_db.RegisterMessage(Posture3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022Posture3DFloatType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/LabelCommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.navigation import ExecutionParameters_pb2 as rst_dot_navigation_dot_ExecutionParameters__pb2
from rst.navigation import MotionParameters_pb2 as rst_dot_navigation_dot_MotionParameters__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/LabelCommand.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n!rst/navigation/LabelCommand.proto\x12\x0erst.navigation\x1a(rst/navigation/ExecutionParameters.proto\x1a%rst/navigation/MotionParameters.proto\"\x9c\x01\n\x0cLabelCommand\x12\x0c\n\x04goal\x18\x01 \x02(\t\x12;\n\x11motion_parameters\x18\x02 \x01(\x0b\x32 .rst.navigation.MotionParameters\x12\x41\n\x14\x65xecution_parameters\x18\x03 \x01(\x0b\x32#.rst.navigation.ExecutionParametersB\x12\x42\x10LabelCommandType')
  ,
  dependencies=[rst_dot_navigation_dot_ExecutionParameters__pb2.DESCRIPTOR,rst_dot_navigation_dot_MotionParameters__pb2.DESCRIPTOR,])




_LABELCOMMAND = _descriptor.Descriptor(
  name='LabelCommand',
  full_name='rst.navigation.LabelCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='goal', full_name='rst.navigation.LabelCommand.goal', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion_parameters', full_name='rst.navigation.LabelCommand.motion_parameters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='execution_parameters', full_name='rst.navigation.LabelCommand.execution_parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=291,
)

_LABELCOMMAND.fields_by_name['motion_parameters'].message_type = rst_dot_navigation_dot_MotionParameters__pb2._MOTIONPARAMETERS
_LABELCOMMAND.fields_by_name['execution_parameters'].message_type = rst_dot_navigation_dot_ExecutionParameters__pb2._EXECUTIONPARAMETERS
DESCRIPTOR.message_types_by_name['LabelCommand'] = _LABELCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LabelCommand = _reflection.GeneratedProtocolMessageType('LabelCommand', (_message.Message,), dict(
  DESCRIPTOR = _LABELCOMMAND,
  __module__ = 'rst.navigation.LabelCommand_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.LabelCommand)
  ))
_sym_db.RegisterMessage(LabelCommand)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020LabelCommandType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPosture3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2
from rst.kinematics import Posture3DFloat_pb2 as rst_dot_kinematics_dot_Posture3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPosture3DFloat.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n(rst/tracking/TrackedPosture3DFloat.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a#rst/kinematics/Posture3DFloat.proto\"\x86\x01\n\x15TrackedPosture3DFloat\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12/\n\x07posture\x18\x02 \x02(\x0b\x32\x1e.rst.kinematics.Posture3DFloat\x12\x12\n\nconfidence\x18\x03 \x03(\x02\x42\x1b\x42\x19TrackedPosture3DFloatType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,rst_dot_kinematics_dot_Posture3DFloat__pb2.DESCRIPTOR,])




_TRACKEDPOSTURE3DFLOAT = _descriptor.Descriptor(
  name='TrackedPosture3DFloat',
  full_name='rst.tracking.TrackedPosture3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPosture3DFloat.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='posture', full_name='rst.tracking.TrackedPosture3DFloat.posture', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.tracking.TrackedPosture3DFloat.confidence', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=263,
)

_TRACKEDPOSTURE3DFLOAT.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_TRACKEDPOSTURE3DFLOAT.fields_by_name['posture'].message_type = rst_dot_kinematics_dot_Posture3DFloat__pb2._POSTURE3DFLOAT
DESCRIPTOR.message_types_by_name['TrackedPosture3DFloat'] = _TRACKEDPOSTURE3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPosture3DFloat = _reflection.GeneratedProtocolMessageType('TrackedPosture3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOSTURE3DFLOAT,
  __module__ = 'rst.tracking.TrackedPosture3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPosture3DFloat)
  ))
_sym_db.RegisterMessage(TrackedPosture3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\031TrackedPosture3DFloatType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPositions3DFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackedPosition3DFloat_pb2 as rst_dot_tracking_dot_TrackedPosition3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPositions3DFloat.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n*rst/tracking/TrackedPositions3DFloat.proto\x12\x0crst.tracking\x1a)rst/tracking/TrackedPosition3DFloat.proto\"Q\n\x17TrackedPositions3DFloat\x12\x36\n\x08position\x18\x01 \x03(\x0b\x32$.rst.tracking.TrackedPosition3DFloatB\x1d\x42\x1bTrackedPositions3DFloatType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackedPosition3DFloat__pb2.DESCRIPTOR,])




_TRACKEDPOSITIONS3DFLOAT = _descriptor.Descriptor(
  name='TrackedPositions3DFloat',
  full_name='rst.tracking.TrackedPositions3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.tracking.TrackedPositions3DFloat.position', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=184,
)

_TRACKEDPOSITIONS3DFLOAT.fields_by_name['position'].message_type = rst_dot_tracking_dot_TrackedPosition3DFloat__pb2._TRACKEDPOSITION3DFLOAT
DESCRIPTOR.message_types_by_name['TrackedPositions3DFloat'] = _TRACKEDPOSITIONS3DFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPositions3DFloat = _reflection.GeneratedProtocolMessageType('TrackedPositions3DFloat', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOSITIONS3DFLOAT,
  __module__ = 'rst.tracking.TrackedPositions3DFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPositions3DFloat)
  ))
_sym_db.RegisterMessage(TrackedPositions3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033TrackedPositions3DFloatType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Point2DTimeseries.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Point2DTimestampPair_pb2 as rst_dot_timing_dot_Point2DTimestampPair__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Point2DTimeseries.proto',
  package='rst.timing',
  syntax='proto2',
  serialized_pb=_b('\n\"rst/timing/Point2DTimeseries.proto\x12\nrst.timing\x1a%rst/timing/Point2DTimestampPair.proto\"D\n\x11Point2DTimeseries\x12/\n\x05\x65ntry\x18\x01 \x03(\x0b\x32 .rst.timing.Point2DTimestampPairB\x17\x42\x15Point2DTimeseriesType')
  ,
  dependencies=[rst_dot_timing_dot_Point2DTimestampPair__pb2.DESCRIPTOR,])




_POINT2DTIMESERIES = _descriptor.Descriptor(
  name='Point2DTimeseries',
  full_name='rst.timing.Point2DTimeseries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='rst.timing.Point2DTimeseries.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=157,
)

_POINT2DTIMESERIES.fields_by_name['entry'].message_type = rst_dot_timing_dot_Point2DTimestampPair__pb2._POINT2DTIMESTAMPPAIR
DESCRIPTOR.message_types_by_name['Point2DTimeseries'] = _POINT2DTIMESERIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Point2DTimeseries = _reflection.GeneratedProtocolMessageType('Point2DTimeseries', (_message.Message,), dict(
  DESCRIPTOR = _POINT2DTIMESERIES,
  __module__ = 'rst.timing.Point2DTimeseries_pb2'
  # @@protoc_insertion_point(class_scope:rst.timing.Point2DTimeseries)
  ))
_sym_db.RegisterMessage(Point2DTimeseries)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\025Point2DTimeseriesType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/Utterance.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.audition import PhonemeCollection_pb2 as rst_dot_audition_dot_PhonemeCollection__pb2
from rst.audition import SoundChunk_pb2 as rst_dot_audition_dot_SoundChunk__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/Utterance.proto',
  package='rst.audition',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/audition/Utterance.proto\x12\x0crst.audition\x1a$rst/audition/PhonemeCollection.proto\x1a\x1drst/audition/SoundChunk.proto\"\x87\x01\n\tUtterance\x12\x31\n\x08phonemes\x18\x01 \x02(\x0b\x32\x1f.rst.audition.PhonemeCollection\x12\'\n\x05\x61udio\x18\x02 \x02(\x0b\x32\x18.rst.audition.SoundChunk\x12\x1e\n\x16textual_representation\x18\x03 \x02(\tB\x0f\x42\rUtteranceType')
  ,
  dependencies=[rst_dot_audition_dot_PhonemeCollection__pb2.DESCRIPTOR,rst_dot_audition_dot_SoundChunk__pb2.DESCRIPTOR,])




_UTTERANCE = _descriptor.Descriptor(
  name='Utterance',
  full_name='rst.audition.Utterance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phonemes', full_name='rst.audition.Utterance.phonemes', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio', full_name='rst.audition.Utterance.audio', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='textual_representation', full_name='rst.audition.Utterance.textual_representation', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=251,
)

_UTTERANCE.fields_by_name['phonemes'].message_type = rst_dot_audition_dot_PhonemeCollection__pb2._PHONEMECOLLECTION
_UTTERANCE.fields_by_name['audio'].message_type = rst_dot_audition_dot_SoundChunk__pb2._SOUNDCHUNK
DESCRIPTOR.message_types_by_name['Utterance'] = _UTTERANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Utterance = _reflection.GeneratedProtocolMessageType('Utterance', (_message.Message,), dict(
  DESCRIPTOR = _UTTERANCE,
  __module__ = 'rst.audition.Utterance_pb2'
  # @@protoc_insertion_point(class_scope:rst.audition.Utterance)
  ))
_sym_db.RegisterMessage(Utterance)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rUtteranceType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/xml/XOP.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/xml/XOP.proto',
  package='rst.xml',
  syntax='proto2',
  serialized_pb=_b('\n\x11rst/xml/XOP.proto\x12\x07rst.xml\"<\n\nAttachment\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0bwire_schema\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"H\n\x03XOP\x12\x0b\n\x03xml\x18\x01 \x01(\t\x12(\n\x0b\x61ttachments\x18\x02 \x03(\x0b\x32\x13.rst.xml.Attachment\x12\n\n\x02id\x18\x03 \x01(\x04\x42\tB\x07XOPType')
)




_ATTACHMENT = _descriptor.Descriptor(
  name='Attachment',
  full_name='rst.xml.Attachment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='rst.xml.Attachment.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wire_schema', full_name='rst.xml.Attachment.wire_schema', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.xml.Attachment.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=90,
)


_XOP = _descriptor.Descriptor(
  name='XOP',
  full_name='rst.xml.XOP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xml', full_name='rst.xml.XOP.xml', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attachments', full_name='rst.xml.XOP.attachments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.xml.XOP.id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=164,
)

_XOP.fields_by_name['attachments'].message_type = _ATTACHMENT
DESCRIPTOR.message_types_by_name['Attachment'] = _ATTACHMENT
DESCRIPTOR.message_types_by_name['XOP'] = _XOP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Attachment = _reflection.GeneratedProtocolMessageType('Attachment', (_message.Message,), dict(
  DESCRIPTOR = _ATTACHMENT,
  __module__ = 'rst.xml.XOP_pb2'
  # @@protoc_insertion_point(class_scope:rst.xml.Attachment)
  ))
_sym_db.RegisterMessage(Attachment)

XOP = _reflection.GeneratedProtocolMessageType('XOP', (_message.Message,), dict(
  DESCRIPTOR = _XOP,
  __module__ = 'rst.xml.XOP_pb2'
  # @@protoc_insertion_point(class_scope:rst.xml.XOP)
  ))
_sym_db.RegisterMessage(XOP)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\007XOPType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/LocatedXYZImage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import ViewFrustum_pb2 as rst_dot_geometry_dot_ViewFrustum__pb2
from rst.geometry import CameraPose_pb2 as rst_dot_geometry_dot_CameraPose__pb2
from rst.vision import SimpleXYZImage_pb2 as rst_dot_vision_dot_SimpleXYZImage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/LocatedXYZImage.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n rst/vision/LocatedXYZImage.proto\x12\nrst.vision\x1a\x1erst/geometry/ViewFrustum.proto\x1a\x1drst/geometry/CameraPose.proto\x1a\x1frst/vision/SimpleXYZImage.proto\"\x92\x01\n\x0fLocatedXYZImage\x12)\n\x05image\x18\x01 \x02(\x0b\x32\x1a.rst.vision.SimpleXYZImage\x12(\n\x06\x63\x61mera\x18\x02 \x02(\x0b\x32\x18.rst.geometry.CameraPose\x12*\n\x07\x66rustum\x18\x03 \x02(\x0b\x32\x19.rst.geometry.ViewFrustumB\x15\x42\x13LocatedXYZImageType')
  ,
  dependencies=[rst_dot_geometry_dot_ViewFrustum__pb2.DESCRIPTOR,rst_dot_geometry_dot_CameraPose__pb2.DESCRIPTOR,rst_dot_vision_dot_SimpleXYZImage__pb2.DESCRIPTOR,])




_LOCATEDXYZIMAGE = _descriptor.Descriptor(
  name='LocatedXYZImage',
  full_name='rst.vision.LocatedXYZImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='rst.vision.LocatedXYZImage.image', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='camera', full_name='rst.vision.LocatedXYZImage.camera', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frustum', full_name='rst.vision.LocatedXYZImage.frustum', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=291,
)

_LOCATEDXYZIMAGE.fields_by_name['image'].message_type = rst_dot_vision_dot_SimpleXYZImage__pb2._SIMPLEXYZIMAGE
_LOCATEDXYZIMAGE.fields_by_name['camera'].message_type = rst_dot_geometry_dot_CameraPose__pb2._CAMERAPOSE
_LOCATEDXYZIMAGE.fields_by_name['frustum'].message_type = rst_dot_geometry_dot_ViewFrustum__pb2._VIEWFRUSTUM
DESCRIPTOR.message_types_by_name['LocatedXYZImage'] = _LOCATEDXYZIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocatedXYZImage = _reflection.GeneratedProtocolMessageType('LocatedXYZImage', (_message.Message,), dict(
  DESCRIPTOR = _LOCATEDXYZIMAGE,
  __module__ = 'rst.vision.LocatedXYZImage_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.LocatedXYZImage)
  ))
_sym_db.RegisterMessage(LocatedXYZImage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023LocatedXYZImageType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedClassifiedRegion3D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2
from rst.classification import ClassifiedRegion3D_pb2 as rst_dot_classification_dot_ClassifiedRegion3D__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedClassifiedRegion3D.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n,rst/tracking/TrackedClassifiedRegion3D.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a+rst/classification/ClassifiedRegion3D.proto\"}\n\x19TrackedClassifiedRegion3D\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12\x36\n\x06region\x18\x02 \x02(\x0b\x32&.rst.classification.ClassifiedRegion3DB\x1f\x42\x1dTrackedClassifiedRegion3DType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,rst_dot_classification_dot_ClassifiedRegion3D__pb2.DESCRIPTOR,])




_TRACKEDCLASSIFIEDREGION3D = _descriptor.Descriptor(
  name='TrackedClassifiedRegion3D',
  full_name='rst.tracking.TrackedClassifiedRegion3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedClassifiedRegion3D.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.tracking.TrackedClassifiedRegion3D.region', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=265,
)

_TRACKEDCLASSIFIEDREGION3D.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_TRACKEDCLASSIFIEDREGION3D.fields_by_name['region'].message_type = rst_dot_classification_dot_ClassifiedRegion3D__pb2._CLASSIFIEDREGION3D
DESCRIPTOR.message_types_by_name['TrackedClassifiedRegion3D'] = _TRACKEDCLASSIFIEDREGION3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedClassifiedRegion3D = _reflection.GeneratedProtocolMessageType('TrackedClassifiedRegion3D', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDCLASSIFIEDREGION3D,
  __module__ = 'rst.tracking.TrackedClassifiedRegion3D_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedClassifiedRegion3D)
  ))
_sym_db.RegisterMessage(TrackedClassifiedRegion3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\035TrackedClassifiedRegion3DType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Entry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import TimeZone_pb2 as rst_dot_calendar_dot_TimeZone__pb2
from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import RecurrenceId_pb2 as rst_dot_calendar_dot_RecurrenceId__pb2
from rst.calendar import Attendee_pb2 as rst_dot_calendar_dot_Attendee__pb2
from rst.calendar import Organizer_pb2 as rst_dot_calendar_dot_Organizer__pb2
from rst.calendar import Recurrence_pb2 as rst_dot_calendar_dot_Recurrence__pb2
from rst.calendar import RequestStatus_pb2 as rst_dot_calendar_dot_RequestStatus__pb2
from rst.calendar import Relationship_pb2 as rst_dot_calendar_dot_Relationship__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Entry.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x18rst/calendar/Entry.proto\x12\x0crst.calendar\x1a\x1brst/calendar/TimeZone.proto\x1a\x1brst/calendar/DateTime.proto\x1a\x1frst/calendar/RecurrenceId.proto\x1a\x1brst/calendar/Attendee.proto\x1a\x1crst/calendar/Organizer.proto\x1a\x1drst/calendar/Recurrence.proto\x1a rst/calendar/RequestStatus.proto\x1a\x1frst/calendar/Relationship.proto\"\xe5\x06\n\x05\x45ntry\x12:\n\nvisibility\x18\x01 \x01(\x0e\x32\x1e.rst.calendar.Entry.Visibility:\x06PUBLIC\x12+\n\x0b\x63reated_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12/\n\x0f\x64\x61te_time_start\x18\x04 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x17\n\x0cgeo_latitude\x18\x05 \x01(\x01:\x01\x30\x12\x18\n\rgeo_longitude\x18\x06 \x01(\x01:\x01\x30\x12-\n\rlast_modified\x18\x07 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x10\n\x08location\x18\x08 \x01(\t\x12*\n\torganizer\x18\t \x01(\x0b\x32\x17.rst.calendar.Organizer\x12\x13\n\x08priority\x18\n \x01(\r:\x01\x30\x12/\n\x0f\x64\x61te_time_stamp\x18\x0b \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x1a\n\x0fsequence_number\x18\x0c \x01(\r:\x01\x30\x12\x0f\n\x07summary\x18\r \x01(\t\x12\x0b\n\x03uid\x18\x0e \x01(\t\x12\x0b\n\x03url\x18\x0f \x01(\t\x12\x31\n\rrecurrence_id\x18\x10 \x01(\x0b\x32\x1a.rst.calendar.RecurrenceId\x12\x0e\n\x06\x61ttach\x18\x11 \x03(\t\x12)\n\tattendees\x18\x12 \x03(\x0b\x32\x16.rst.calendar.Attendee\x12\x12\n\ncategories\x18\x13 \x03(\t\x12\x10\n\x08\x63omments\x18\x14 \x03(\t\x12\x10\n\x08\x63ontacts\x18\x15 \x03(\t\x12,\n\nrecurrence\x18\x16 \x01(\x0b\x32\x18.rst.calendar.Recurrence\x12\x33\n\x0erequest_status\x18\x17 \x03(\x0b\x32\x1b.rst.calendar.RequestStatus\x12+\n\x07related\x18\x18 \x03(\x0b\x32\x1a.rst.calendar.Relationship\x12\x11\n\tresources\x18\x19 \x03(\t\"7\n\nVisibility\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x12\x10\n\x0c\x43ONFIDENTIAL\x10\x03\x42\x0b\x42\tEntryType')
  ,
  dependencies=[rst_dot_calendar_dot_TimeZone__pb2.DESCRIPTOR,rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_RecurrenceId__pb2.DESCRIPTOR,rst_dot_calendar_dot_Attendee__pb2.DESCRIPTOR,rst_dot_calendar_dot_Organizer__pb2.DESCRIPTOR,rst_dot_calendar_dot_Recurrence__pb2.DESCRIPTOR,rst_dot_calendar_dot_RequestStatus__pb2.DESCRIPTOR,rst_dot_calendar_dot_Relationship__pb2.DESCRIPTOR,])



_ENTRY_VISIBILITY = _descriptor.EnumDescriptor(
  name='Visibility',
  full_name='rst.calendar.Entry.Visibility',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIDENTIAL', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1105,
  serialized_end=1160,
)
_sym_db.RegisterEnumDescriptor(_ENTRY_VISIBILITY)


_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='rst.calendar.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='visibility', full_name='rst.calendar.Entry.visibility', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_utc', full_name='rst.calendar.Entry.created_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='rst.calendar.Entry.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_time_start', full_name='rst.calendar.Entry.date_time_start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='geo_latitude', full_name='rst.calendar.Entry.geo_latitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='geo_longitude', full_name='rst.calendar.Entry.geo_longitude', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified', full_name='rst.calendar.Entry.last_modified', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.calendar.Entry.location', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='organizer', full_name='rst.calendar.Entry.organizer', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='rst.calendar.Entry.priority', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='date_time_stamp', full_name='rst.calendar.Entry.date_time_stamp', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='rst.calendar.Entry.sequence_number', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='summary', full_name='rst.calendar.Entry.summary', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='rst.calendar.Entry.uid', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='rst.calendar.Entry.url', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence_id', full_name='rst.calendar.Entry.recurrence_id', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attach', full_name='rst.calendar.Entry.attach', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attendees', full_name='rst.calendar.Entry.attendees', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='categories', full_name='rst.calendar.Entry.categories', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comments', full_name='rst.calendar.Entry.comments', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contacts', full_name='rst.calendar.Entry.contacts', index=20,
      number=21, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence', full_name='rst.calendar.Entry.recurrence', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_status', full_name='rst.calendar.Entry.request_status', index=22,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='related', full_name='rst.calendar.Entry.related', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resources', full_name='rst.calendar.Entry.resources', index=24,
      number=25, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ENTRY_VISIBILITY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=1160,
)

_ENTRY.fields_by_name['visibility'].enum_type = _ENTRY_VISIBILITY
_ENTRY.fields_by_name['created_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['date_time_start'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['last_modified'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['organizer'].message_type = rst_dot_calendar_dot_Organizer__pb2._ORGANIZER
_ENTRY.fields_by_name['date_time_stamp'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_ENTRY.fields_by_name['recurrence_id'].message_type = rst_dot_calendar_dot_RecurrenceId__pb2._RECURRENCEID
_ENTRY.fields_by_name['attendees'].message_type = rst_dot_calendar_dot_Attendee__pb2._ATTENDEE
_ENTRY.fields_by_name['recurrence'].message_type = rst_dot_calendar_dot_Recurrence__pb2._RECURRENCE
_ENTRY.fields_by_name['request_status'].message_type = rst_dot_calendar_dot_RequestStatus__pb2._REQUESTSTATUS
_ENTRY.fields_by_name['related'].message_type = rst_dot_calendar_dot_Relationship__pb2._RELATIONSHIP
_ENTRY_VISIBILITY.containing_type = _ENTRY
DESCRIPTOR.message_types_by_name['Entry'] = _ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
  DESCRIPTOR = _ENTRY,
  __module__ = 'rst.calendar.Entry_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Entry)
  ))
_sym_db.RegisterMessage(Entry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tEntryType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/FaceWithGaze.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import Face_pb2 as rst_dot_vision_dot_Face__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/FaceWithGaze.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/vision/FaceWithGaze.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\"\x8a\x01\n\x0c\x46\x61\x63\x65WithGaze\x12 \n\x06region\x18\x01 \x02(\x0b\x32\x10.rst.vision.Face\x12\x12\n\nlid_closed\x18\x02 \x01(\x08\x12\"\n\x1ahorizontal_gaze_estimation\x18\x03 \x01(\x01\x12 \n\x18vertical_gaze_estimation\x18\x04 \x01(\x01\x42\x12\x42\x10\x46\x61\x63\x65WithGazeType')
  ,
  dependencies=[rst_dot_vision_dot_Face__pb2.DESCRIPTOR,])




_FACEWITHGAZE = _descriptor.Descriptor(
  name='FaceWithGaze',
  full_name='rst.vision.FaceWithGaze',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.FaceWithGaze.region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lid_closed', full_name='rst.vision.FaceWithGaze.lid_closed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='horizontal_gaze_estimation', full_name='rst.vision.FaceWithGaze.horizontal_gaze_estimation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vertical_gaze_estimation', full_name='rst.vision.FaceWithGaze.vertical_gaze_estimation', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=207,
)

_FACEWITHGAZE.fields_by_name['region'].message_type = rst_dot_vision_dot_Face__pb2._FACE
DESCRIPTOR.message_types_by_name['FaceWithGaze'] = _FACEWITHGAZE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceWithGaze = _reflection.GeneratedProtocolMessageType('FaceWithGaze', (_message.Message,), dict(
  DESCRIPTOR = _FACEWITHGAZE,
  __module__ = 'rst.vision.FaceWithGaze_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.FaceWithGaze)
  ))
_sym_db.RegisterMessage(FaceWithGaze)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020FaceWithGazeType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/Vec3DInt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/Vec3DInt.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x17rst/math/Vec3DInt.proto\x12\x08rst.math\"4\n\x08Vec3DInt\x12\x0c\n\x01x\x18\x01 \x02(\x05:\x01\x30\x12\x0c\n\x01y\x18\x02 \x02(\x05:\x01\x30\x12\x0c\n\x01z\x18\x03 \x02(\x05:\x01\x30\x42\x0e\x42\x0cVec3DIntType')
)




_VEC3DINT = _descriptor.Descriptor(
  name='Vec3DInt',
  full_name='rst.math.Vec3DInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.math.Vec3DInt.x', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.math.Vec3DInt.y', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.math.Vec3DInt.z', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=89,
)

DESCRIPTOR.message_types_by_name['Vec3DInt'] = _VEC3DINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vec3DInt = _reflection.GeneratedProtocolMessageType('Vec3DInt', (_message.Message,), dict(
  DESCRIPTOR = _VEC3DINT,
  __module__ = 'rst.math.Vec3DInt_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.Vec3DInt)
  ))
_sym_db.RegisterMessage(Vec3DInt)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014Vec3DIntType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/scene/SceneObject.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2
from rst.geometry import Shape3DFloat_pb2 as rst_dot_geometry_dot_Shape3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/scene/SceneObject.proto',
  package='rst.scene',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/scene/SceneObject.proto\x12\trst.scene\x1a\x17rst/geometry/Pose.proto\x1a\x1frst/geometry/Shape3DFloat.proto\"x\n\x0bSceneObject\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\"\n\x06\x63\x65nter\x18\x03 \x02(\x0b\x32\x12.rst.geometry.Pose\x12)\n\x05shape\x18\x04 \x01(\x0b\x32\x1a.rst.geometry.Shape3DFloatB\x11\x42\x0fSceneObjectType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,rst_dot_geometry_dot_Shape3DFloat__pb2.DESCRIPTOR,])




_SCENEOBJECT = _descriptor.Descriptor(
  name='SceneObject',
  full_name='rst.scene.SceneObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.scene.SceneObject.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kind', full_name='rst.scene.SceneObject.kind', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='center', full_name='rst.scene.SceneObject.center', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shape', full_name='rst.scene.SceneObject.shape', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=220,
)

_SCENEOBJECT.fields_by_name['center'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
_SCENEOBJECT.fields_by_name['shape'].message_type = rst_dot_geometry_dot_Shape3DFloat__pb2._SHAPE3DFLOAT
DESCRIPTOR.message_types_by_name['SceneObject'] = _SCENEOBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SceneObject = _reflection.GeneratedProtocolMessageType('SceneObject', (_message.Message,), dict(
  DESCRIPTOR = _SCENEOBJECT,
  __module__ = 'rst.scene.SceneObject_pb2'
  # @@protoc_insertion_point(class_scope:rst.scene.SceneObject)
  ))
_sym_db.RegisterMessage(SceneObject)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017SceneObjectType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/ObjectCollision.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.kinematics import CollisionGeometry_pb2 as rst_dot_kinematics_dot_CollisionGeometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/ObjectCollision.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n$rst/kinematics/ObjectCollision.proto\x12\x0erst.kinematics\x1a&rst/kinematics/CollisionGeometry.proto\"j\n\x0fObjectCollision\x12\x33\n\x08geometry\x18\x01 \x01(\x0b\x32!.rst.kinematics.CollisionGeometry\x12\x10\n\x08object_1\x18\x02 \x01(\t\x12\x10\n\x08object_2\x18\x03 \x01(\tB\x15\x42\x13ObjectCollisionType')
  ,
  dependencies=[rst_dot_kinematics_dot_CollisionGeometry__pb2.DESCRIPTOR,])




_OBJECTCOLLISION = _descriptor.Descriptor(
  name='ObjectCollision',
  full_name='rst.kinematics.ObjectCollision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geometry', full_name='rst.kinematics.ObjectCollision.geometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_1', full_name='rst.kinematics.ObjectCollision.object_1', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='object_2', full_name='rst.kinematics.ObjectCollision.object_2', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=202,
)

_OBJECTCOLLISION.fields_by_name['geometry'].message_type = rst_dot_kinematics_dot_CollisionGeometry__pb2._COLLISIONGEOMETRY
DESCRIPTOR.message_types_by_name['ObjectCollision'] = _OBJECTCOLLISION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObjectCollision = _reflection.GeneratedProtocolMessageType('ObjectCollision', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTCOLLISION,
  __module__ = 'rst.kinematics.ObjectCollision_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.ObjectCollision)
  ))
_sym_db.RegisterMessage(ObjectCollision)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023ObjectCollisionType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/graph/Node.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.generic import Value_pb2 as rst_dot_generic_dot_Value__pb2
from rst.generic import Dictionary_pb2 as rst_dot_generic_dot_Dictionary__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/graph/Node.proto',
  package='rst.graph',
  syntax='proto2',
  serialized_pb=_b('\n\x14rst/graph/Node.proto\x12\trst.graph\x1a\x17rst/generic/Value.proto\x1a\x1crst/generic/Dictionary.proto\"U\n\x04Node\x12 \n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x12.rst.generic.Value\x12+\n\nproperties\x18\x02 \x01(\x0b\x32\x17.rst.generic.DictionaryB\nB\x08NodeType')
  ,
  dependencies=[rst_dot_generic_dot_Value__pb2.DESCRIPTOR,rst_dot_generic_dot_Dictionary__pb2.DESCRIPTOR,])




_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='rst.graph.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.graph.Node.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rst.graph.Node.properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=175,
)

_NODE.fields_by_name['data'].message_type = rst_dot_generic_dot_Value__pb2._VALUE
_NODE.fields_by_name['properties'].message_type = rst_dot_generic_dot_Dictionary__pb2._DICTIONARY
DESCRIPTOR.message_types_by_name['Node'] = _NODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'rst.graph.Node_pb2'
  # @@protoc_insertion_point(class_scope:rst.graph.Node)
  ))
_sym_db.RegisterMessage(Node)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010NodeType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Observance.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2
from rst.calendar import Recurrence_pb2 as rst_dot_calendar_dot_Recurrence__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Observance.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/calendar/Observance.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x1drst/calendar/Recurrence.proto\"\xfc\x01\n\nObservance\x12\x35\n\x04type\x18\x03 \x02(\x0e\x32\x1d.rst.calendar.Observance.Type:\x08STANDARD\x12)\n\tstart_utc\x18\x04 \x02(\x0b\x32\x16.rst.calendar.DateTime\x12\x0c\n\x04name\x18\x06 \x01(\t\x12,\n\nrecurrence\x18\x07 \x01(\x0b\x32\x18.rst.calendar.Recurrence\x12\x16\n\x0boffset_from\x18\x08 \x02(\x12:\x01\x30\x12\x14\n\toffset_to\x18\t \x02(\x12:\x01\x30\"\"\n\x04Type\x12\x0c\n\x08STANDARD\x10\x01\x12\x0c\n\x08\x44\x41YLIGHT\x10\x02\x42\x10\x42\x0eObservanceType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,rst_dot_calendar_dot_Recurrence__pb2.DESCRIPTOR,])



_OBSERVANCE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.Observance.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STANDARD', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAYLIGHT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=326,
  serialized_end=360,
)
_sym_db.RegisterEnumDescriptor(_OBSERVANCE_TYPE)


_OBSERVANCE = _descriptor.Descriptor(
  name='Observance',
  full_name='rst.calendar.Observance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.calendar.Observance.type', index=0,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_utc', full_name='rst.calendar.Observance.start_utc', index=1,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.calendar.Observance.name', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recurrence', full_name='rst.calendar.Observance.recurrence', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_from', full_name='rst.calendar.Observance.offset_from', index=4,
      number=8, type=18, cpp_type=2, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset_to', full_name='rst.calendar.Observance.offset_to', index=5,
      number=9, type=18, cpp_type=2, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSERVANCE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=360,
)

_OBSERVANCE.fields_by_name['type'].enum_type = _OBSERVANCE_TYPE
_OBSERVANCE.fields_by_name['start_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_OBSERVANCE.fields_by_name['recurrence'].message_type = rst_dot_calendar_dot_Recurrence__pb2._RECURRENCE
_OBSERVANCE_TYPE.containing_type = _OBSERVANCE
DESCRIPTOR.message_types_by_name['Observance'] = _OBSERVANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Observance = _reflection.GeneratedProtocolMessageType('Observance', (_message.Message,), dict(
  DESCRIPTOR = _OBSERVANCE,
  __module__ = 'rst.calendar.Observance_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Observance)
  ))
_sym_db.RegisterMessage(Observance)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016ObservanceType'))
# @@protoc_insertion_point(module_scope)
